#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-AoBi9UNabQ7ILz6PzJDZvc
key:                  heapsize-0.3.0.1-AoBi9UNabQ7ILz6PzJDZvc
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  1300f998ef224501c79a56e440cd5160
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-AoBi9UNabQ7ILz6PzJDZvc
depends:
    base-4.18.2.1 deepseq-1.4.8.1 exceptions-0.10.7 ghc-heap-9.6.6
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW
    hashtables-1.4.2-FXKKfWXYU66CoknsSsqXHx
    primitive-0.9.1.0-L1eqoi3SeaLKLAId8dPuVE transformers-0.6.1.0
    unordered-containers-0.2.20.1-9wZ7uB8CqcR5TZZg4U4qth

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

